PhysRegHandle

Enum PhysRegHandle 

pub enum PhysRegHandle {
    Named(&'static str),
}
Opaque handle that allows dynamic dispatch over register allocators without leaking architecture-specific physical register types.

Variants



Named(&'static str)

Physical registers represented by their canonical assembly name.

Implementations

Source

impl PhysRegHandle

pub fn as_named(self) -> Option<&'static str>

Retrieve the assembly name if the handle stores one.