Cross-platform target support for code generation.
This module defines which (architecture, OS) combinations are supported for assembly and binary emission, so callers can cross-compile to a different target than the host.
Functions
- is_
assembly_ supported - Returns true if assembly text generation is supported for this (arch, os).
- os_
uses_ coff - Returns true if the given OS uses COFF/PE (Windows).
- os_
uses_ elf - Returns true if the given OS uses ELF object format (Linux, BSD, Redox).
- os_
uses_ macho - Returns true if the given OS uses Mach-O (macOS).
- supported_
assembly_ targets_ hint - Returns a short description of supported targets for error messages.