pub struct WasmRegAlloc { /* private fields */ }Expand description
WASM “register allocator” for stack-based virtual machine.
WASM doesn’t use physical registers like x86_64, but we still need to track virtual registers for stack operations. This is a simplified allocator that maps virtual registers to stack positions.
Implementations
Sourceimpl WasmRegAlloc
impl WasmRegAlloc
pub fn new() -> Self
Sourcepub fn get_stack_position(&self, vreg: &VirtualReg) -> Option<u32>
pub fn get_stack_position(&self, vreg: &VirtualReg) -> Option<u32>
Get the stack position for a virtual register
Sourcepub fn allocate_stack(&mut self, vreg: VirtualReg) -> u32
pub fn allocate_stack(&mut self, vreg: VirtualReg) -> u32
Allocate a stack position for a virtual register