pub struct X64RegAlloc { /* private fields */ }Expand description
x86_64 register allocator supporting System V AMD64 and Microsoft x64 ABIs.
Uses platform-appropriate GPR pools for stable virtual-to-physical register mappings and separate scratch pools for short-lived temporaries.
Implementations
Sourceimpl X64RegAlloc
impl X64RegAlloc
Sourcepub fn new(target_os: TargetOperatingSystem) -> Self
pub fn new(target_os: TargetOperatingSystem) -> Self
Creates a new register allocator for the specified target OS.
Sourcepub fn new_default() -> Self
pub fn new_default() -> Self
Creates a new register allocator with default target OS (Linux).
Sourcepub fn set_conservative_mode(&mut self)
pub fn set_conservative_mode(&mut self)
Sets conservative mode for complex functions, using fewer registers to reduce pressure.
pub fn alloc_scratch(&mut self) -> Option<&'static str>
pub fn free_scratch(&mut self, phys: &'static str)
pub fn is_occupied(&self, phys: &'static str) -> bool
pub fn occupy(&mut self, phys: &'static str)
pub fn release(&mut self, phys: &'static str)
pub fn get_mapping_for(&self, v: &VirtualReg) -> Option<&'static str>
pub fn ensure_mapping(&mut self, v: VirtualReg) -> Option<&'static str>
pub fn ensure_mapping_for_gpr(&mut self, v: VirtualReg) -> Option<&'static str>
pub fn mapped_for_register(&self, r: &Register) -> Option<&'static str>